@@ -1,17 +1,24 @@
 # flake8: noqa
-__version__ = "0.6.0"
+__version__ = "0.6.1"
 __author__ = "DESHIMA software team"
 
 
+# subpackages
+from . import core
+
+
+# submodules
+from . import io
+from . import models
+from . import logging
+from . import plot
 from . import utils
+
+
+# aliases
 from .core import *
-from . import io
-from . import plot
 from .logging import *
-from . import models
 
-del core
-del logging
 
 # for sphinx docs
 __all__ = dir()
